@@ -19,9 +19,9 @@
 ###################################################################################################
 
 spotFuncStartMexicanHat <- function(spotConfig){
-	pdFile=spotConfig$io.apdFileName;
-	resFileName=spotConfig$io.resFileName;	
-	desFileName=spotConfig$io.desFileName;	
+	pdFile=spotConfig$io.apdFileName
+	resFileName=spotConfig$io.resFileName	
+	desFileName=spotConfig$io.desFileName
 	if(is.null(spotConfig$spot.noise)){spotConfig$spot.noise=10.0}
 	if(is.null(spotConfig$spot.noise.type)){spotConfig$spot.noise.type="weighted"}
 	if(is.null(spotConfig$spot.noise.minimum.at.value)){spotConfig$spot.noise.minimum.at.value=0.0}
@@ -29,44 +29,43 @@ spotFuncStartMexicanHat <- function(spotConfig){
 	## weighted: y = y + y * noiseValue / 100
 	## constant: y = y + noiseValue
 	
-	if (spotConfig$spot.fileMode){ ##Check if spotConfig was passed to the algorithm, if yes the spot.fileMode is chosen with False wich means results have to be passed to spotConfig and not to res file.
-		spotWriteLines(spotConfig$io.verbosity,1,paste("Loading design file data from::",  desFileName), con=stderr());
+	if (spotConfig$spot.fileMode){ 
+		spotWriteLines(spotConfig$io.verbosity,1,paste("Loading design file data from::",  desFileName), con=stderr())
 		## read doe/dace etc settings:
-		des <- read.table(desFileName, sep=" ", header = TRUE);	
+		des <- read.table(desFileName, sep=" ", header = TRUE)	
 	}else{
-		des <- spotConfig$alg.currentDesign; ##The if/else should not be necessary anymore, since des will always be written into the spotConfig
+		des <- spotConfig$alg.currentDesign 
 	}
-	spotPrint(spotConfig$io.verbosity,1,summary(des));
-	spotWriteLines(spotConfig$io.verbosity,1,"Mexican Hat run...", con=stderr());
+	spotPrint(spotConfig$io.verbosity,1,summary(des))
+	spotWriteLines(spotConfig$io.verbosity,1,"Mexican Hat run...", con=stderr())
 	spotPrint(spotConfig$io.verbosity,1,pdFile)
 	#default Values that can be changed with apd file
-    noise<-spotConfig$spot.noise;
-	noise.type <- spotConfig$spot.noise.type;
-	spot.noise.minimum.at.value <- spotConfig$spot.noise.minimum.at.value;
+    noise<-spotConfig$spot.noise
+	noise.type <- spotConfig$spot.noise.type
+	spot.noise.minimum.at.value <- spotConfig$spot.noise.minimum.at.value
 	f<-"MexicanHat"
-	n<-2;
+	n<-2
 	## read problem design file
 	if(file.exists(pdFile)){
 		source(pdFile,local=TRUE)
 	}
 	##  VARX1 VARX2 REPEATS SEED
-	config<-nrow(des);
-	spotPrint(spotConfig$io.verbosity,1,config);
-	attach(des)		
+	config<-nrow(des)
+	spotPrint(spotConfig$io.verbosity,1,config)
 	for (k in 1:config){
 		for (i in 1:des$REPEATS[k]){
 			##
-			if (exists("VARX1")){
+			if (!is.null(des$VARX1)){
 				x1 <- des$VARX1[k]
 			}
-			if (exists("VARX2")){
+			if (!is.null(des$VARX2)){
 				x2 <- des$VARX2[k]
 			}
 			conf <- k
-			if (exists("CONFIG")){
+			if (!is.null(des$CONFIG)){
 				conf <- des$CONFIG[k]
 			}
-			if (exists("STEP")){
+			if (!is.null(des$STEP)){
 				step <- des$STEP[k]
 			}
 			seed <- des$SEED[k]+i-1			
@@ -84,8 +83,7 @@ spotFuncStartMexicanHat <- function(spotConfig){
 					DIM=n,
 					STEP=step,
 					SEED=seed,
-					CONFIG=conf
-			)
+					CONFIG=conf)
 			res <-data.frame(res)
 			if (spotConfig$spot.fileMode){ ##Log the result in the .res file, only if user didnt set fileMode==FALSE
 				colNames = TRUE
@@ -99,12 +97,10 @@ spotFuncStartMexicanHat <- function(spotConfig){
 						, col.names = colNames
 						, sep = " "              
 						, append = !colNames
-						, quote = FALSE
-				);		
+						, quote = FALSE)
 			}
-			spotConfig$alg.currentResult=rbind(spotConfig$alg.currentResult,res);	#always log the results in spotConfig				
+			spotConfig$alg.currentResult=rbind(spotConfig$alg.currentResult,res)	#always log the results in spotConfig				
 		}			
 	}	
-	detach(des)
-	return(spotConfig);
+	spotConfig
 }
