@@ -17,9 +17,9 @@
 #' @keywords internal
 ###################################################################################################
 spotFuncStartRastrigin <- function(spotConfig){
-	pdFile=spotConfig$io.apdFileName;
-	resFileName=spotConfig$io.resFileName;	
-	desFileName=spotConfig$io.desFileName;	
+	pdFile=spotConfig$io.apdFileName
+	resFileName=spotConfig$io.resFileName
+	desFileName=spotConfig$io.desFileName
 	if(is.null(spotConfig$spot.noise)){spotConfig$spot.noise=10.0}
 	if(is.null(spotConfig$spot.noise.type)){spotConfig$spot.noise.type="weighted"}
 	if(is.null(spotConfig$spot.noise.minimum.at.value)){spotConfig$spot.noise.minimum.at.value=0.0}
@@ -27,15 +27,15 @@ spotFuncStartRastrigin <- function(spotConfig){
 	## weighted: y = y + y * noiseValue / 100
 	## constant: y = y + noiseValue
 		
-	if (spotConfig$spot.fileMode){ ##Check if spotConfig was passed to the algorithm, if yes the spot.fileMode is chosen with False wich means results have to be passed to spotConfig and not to res file.
-		spotWriteLines(spotConfig$io.verbosity,1,paste("Loading design file data from::",  desFileName), con=stderr());
+	if (spotConfig$spot.fileMode){ 
+		spotWriteLines(spotConfig$io.verbosity,1,paste("Loading design file data from::",  desFileName), con=stderr())
 		## read doe/dace etc settings:
-		des <- read.table(desFileName, sep=" ", header = TRUE);	
+		des <- read.table(desFileName, sep=" ", header = TRUE)
 	}else{
-		des <- spotConfig$alg.currentDesign; ##The if/else should not be necessary anymore, since des will always be written into the spotConfig
+		des <- spotConfig$alg.currentDesign 
 	}
-	spotPrint(spotConfig$io.verbosity,1,summary(des));
-	spotWriteLines(spotConfig$io.verbosity,1,"spotFuncStartRastrigin...", con=stderr());
+	spotPrint(spotConfig$io.verbosity,1,summary(des))
+	spotWriteLines(spotConfig$io.verbosity,1,"spotFuncStartRastrigin...", con=stderr())
 	spotPrint(spotConfig$io.verbosity,1,pdFile)
 	#default Values that can be changed with apd file
 	noise<-spotConfig$spot.noise
@@ -47,14 +47,13 @@ spotFuncStartRastrigin <- function(spotConfig){
 		source(pdFile,local=TRUE)
 	}
 	##  VARX1 VARX2 REPEATS SEED
-	config<-nrow(des);
-	spotPrint(spotConfig$io.verbosity,1,config);
-	attach(des)	
+	config<-nrow(des)
+	spotPrint(spotConfig$io.verbosity,1,config)
 	for (k in 1:config){
 		for (i in 1:des$REPEATS[k]){
 			dimcounter <- 1
 			x <- NULL			
-			while (exists(paste("VARX", dimcounter, sep=""))){
+			while (!is.null(des[[paste("VARX", dimcounter, sep="")]])){
 				name <- paste("VARX", dimcounter, sep="")
 				varHelper  <- des[name]
 				x <- cbind(x,varHelper[k,1])
@@ -64,17 +63,17 @@ spotFuncStartRastrigin <- function(spotConfig){
 			x <- t(x)
 			n <- dimcounter - 1
 			conf <- k
-			if (exists("CONFIG")){
+			if (!is.null(des$CONFIG)){
 				conf <- des$CONFIG[k]
 			}
-			if (exists("STEP")){
+			if (!is.null(des$STEP)){
 				step <- des$STEP[k]
 			}
 			seed <- des$SEED[k]+i-1			
 			spotPrint(spotConfig$io.verbosity,1,c("Config:",k ," Repeat:",i))
 			y <- spotRastriginFunction(x)
 			## add noise
-			y <- y + spotCalcNoise(y, noise=noise, noise.type=noise.type, spot.noise.minimum.at.value=spot.noise.minimum.at.value);
+			y <- y + spotCalcNoise(y, noise=noise, noise.type=noise.type, spot.noise.minimum.at.value=spot.noise.minimum.at.value)
 			spotPrint(spotConfig$io.verbosity,1,y)
 			res <- NULL
 			res <- list(Y=y,					
@@ -104,58 +103,10 @@ spotFuncStartRastrigin <- function(spotConfig){
 						, col.names = colNames
 						, sep = " "              
 						, append = !colNames
-						, quote = FALSE
-				);		
+						, quote = FALSE)		
 			}
-			spotConfig$alg.currentResult=rbind(spotConfig$alg.currentResult,res);							
+			spotConfig$alg.currentResult=rbind(spotConfig$alg.currentResult,res)					
 		}			
 	}	
-	detach(des)
-	return(spotConfig)
-}
-#
-#	
-#	
-#	
-#	
-#	config<-nrow(des);
-#	print(config);
-#	if (is.null(des$CONFIG))
-#	   stop("Design file is missing the required column CONFIG!")	   
-#	for (k in 1:config){	 
-#		for (i in 1:des$REPEATS[k]){
-#			x1=des$x1[k]
-#			x2=des$x2[k]			
-#  		conf <- des$CONFIG[k]
-#			seed <- des$SEED[k]+i			
-#			cat(sprintf("Config: %5d,   Repeat: %5d\n",conf,i))		
-#			browser()
-#			y <- spotRastriginFunction(x1,x2,noise)
-#			print(y)
-#			res <- NULL
-#			res <- list(Y=y
-#					     ,x1=x1
-#					     ,x2=x2
-#					     ,SEED=seed
-#					     ,CONFIG=conf                  
-#					     ,REP=i
-#			)
-#			res <-data.frame(res)
-#			colNames = TRUE
-#			if (file.exists(resFileName)){
-#				colNames = FALSE
-#			}		
-#			
-#			write.table(res
-#					, file = resFileName
-#					, row.names = FALSE
-#					, col.names = colNames
-#					, sep = " "              
-#					, append = !colNames               
-#					, quote = FALSE
-#			);			
-#		}	# for (i)	 
-#	}	# for (k)	
-#}
-#
-#
+	spotConfig
+}
\ No newline at end of file
